feature

package
v0.0.0-...-67bf1eb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the feature type in the database.
	Label = "feature"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldIndx holds the string denoting the indx field in the database.
	FieldIndx = "indx"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDesc holds the string denoting the desc field in the database.
	FieldDesc = "desc"
	// FieldLevel holds the string denoting the level field in the database.
	FieldLevel = "level"
	// EdgePrerequisites holds the string denoting the prerequisites edge name in mutations.
	EdgePrerequisites = "prerequisites"
	// Table holds the table name of the feature in the database.
	Table = "features"
	// PrerequisitesTable is the table that holds the prerequisites relation/edge.
	PrerequisitesTable = "prerequisites"
	// PrerequisitesInverseTable is the table name for the Prerequisite entity.
	// It exists in this package in order to avoid circular dependency with the "prerequisite" package.
	PrerequisitesInverseTable = "prerequisites"
	// PrerequisitesColumn is the table column denoting the prerequisites relation/edge.
	PrerequisitesColumn = "feature_prerequisites"
)

Variables

var (
	// IndxValidator is a validator for the "indx" field. It is called by the builders before save.
	IndxValidator func(string) error
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// LevelValidator is a validator for the "level" field. It is called by the builders before save.
	LevelValidator func(int) error
)

Columns holds all SQL columns for feature fields.

Functions

func And

func And(predicates ...predicate.Feature) predicate.Feature

And groups predicates with the AND operator between them.

func DescIsNil

func DescIsNil() predicate.Feature

DescIsNil applies the IsNil predicate on the "desc" field.

func DescNotNil

func DescNotNil() predicate.Feature

DescNotNil applies the NotNil predicate on the "desc" field.

func HasPrerequisites

func HasPrerequisites() predicate.Feature

HasPrerequisites applies the HasEdge predicate on the "prerequisites" edge.

func HasPrerequisitesWith

func HasPrerequisitesWith(preds ...predicate.Prerequisite) predicate.Feature

HasPrerequisitesWith applies the HasEdge predicate on the "prerequisites" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.Feature

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Feature

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Feature

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Feature

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Feature

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Feature

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Feature

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Feature

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Feature

IDNotIn applies the NotIn predicate on the ID field.

func Indx

func Indx(v string) predicate.Feature

Indx applies equality check predicate on the "indx" field. It's identical to IndxEQ.

func IndxContains

func IndxContains(v string) predicate.Feature

IndxContains applies the Contains predicate on the "indx" field.

func IndxContainsFold

func IndxContainsFold(v string) predicate.Feature

IndxContainsFold applies the ContainsFold predicate on the "indx" field.

func IndxEQ

func IndxEQ(v string) predicate.Feature

IndxEQ applies the EQ predicate on the "indx" field.

func IndxEqualFold

func IndxEqualFold(v string) predicate.Feature

IndxEqualFold applies the EqualFold predicate on the "indx" field.

func IndxGT

func IndxGT(v string) predicate.Feature

IndxGT applies the GT predicate on the "indx" field.

func IndxGTE

func IndxGTE(v string) predicate.Feature

IndxGTE applies the GTE predicate on the "indx" field.

func IndxHasPrefix

func IndxHasPrefix(v string) predicate.Feature

IndxHasPrefix applies the HasPrefix predicate on the "indx" field.

func IndxHasSuffix

func IndxHasSuffix(v string) predicate.Feature

IndxHasSuffix applies the HasSuffix predicate on the "indx" field.

func IndxIn

func IndxIn(vs ...string) predicate.Feature

IndxIn applies the In predicate on the "indx" field.

func IndxLT

func IndxLT(v string) predicate.Feature

IndxLT applies the LT predicate on the "indx" field.

func IndxLTE

func IndxLTE(v string) predicate.Feature

IndxLTE applies the LTE predicate on the "indx" field.

func IndxNEQ

func IndxNEQ(v string) predicate.Feature

IndxNEQ applies the NEQ predicate on the "indx" field.

func IndxNotIn

func IndxNotIn(vs ...string) predicate.Feature

IndxNotIn applies the NotIn predicate on the "indx" field.

func Level

func Level(v int) predicate.Feature

Level applies equality check predicate on the "level" field. It's identical to LevelEQ.

func LevelEQ

func LevelEQ(v int) predicate.Feature

LevelEQ applies the EQ predicate on the "level" field.

func LevelGT

func LevelGT(v int) predicate.Feature

LevelGT applies the GT predicate on the "level" field.

func LevelGTE

func LevelGTE(v int) predicate.Feature

LevelGTE applies the GTE predicate on the "level" field.

func LevelIn

func LevelIn(vs ...int) predicate.Feature

LevelIn applies the In predicate on the "level" field.

func LevelLT

func LevelLT(v int) predicate.Feature

LevelLT applies the LT predicate on the "level" field.

func LevelLTE

func LevelLTE(v int) predicate.Feature

LevelLTE applies the LTE predicate on the "level" field.

func LevelNEQ

func LevelNEQ(v int) predicate.Feature

LevelNEQ applies the NEQ predicate on the "level" field.

func LevelNotIn

func LevelNotIn(vs ...int) predicate.Feature

LevelNotIn applies the NotIn predicate on the "level" field.

func Name

func Name(v string) predicate.Feature

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Feature

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Feature

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Feature

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Feature

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Feature

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Feature

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Feature

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Feature

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Feature

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Feature

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Feature

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Feature

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Feature

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Feature) predicate.Feature

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Feature queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIndx

func ByIndx(opts ...sql.OrderTermOption) OrderOption

ByIndx orders the results by the indx field.

func ByLevel

func ByLevel(opts ...sql.OrderTermOption) OrderOption

ByLevel orders the results by the level field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByPrerequisites

func ByPrerequisites(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByPrerequisites orders the results by prerequisites terms.

func ByPrerequisitesCount

func ByPrerequisitesCount(opts ...sql.OrderTermOption) OrderOption

ByPrerequisitesCount orders the results by prerequisites count.

Jump to