rulesection

package
v0.0.0-...-67bf1eb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the rulesection type in the database.
	Label = "rule_section"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldIndx holds the string denoting the indx field in the database.
	FieldIndx = "indx"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDesc holds the string denoting the desc field in the database.
	FieldDesc = "desc"
	// EdgeRule holds the string denoting the rule edge name in mutations.
	EdgeRule = "rule"
	// Table holds the table name of the rulesection in the database.
	Table = "rule_sections"
	// RuleTable is the table that holds the rule relation/edge.
	RuleTable = "rule_sections"
	// RuleInverseTable is the table name for the Rule entity.
	// It exists in this package in order to avoid circular dependency with the "rule" package.
	RuleInverseTable = "rules"
	// RuleColumn is the table column denoting the rule relation/edge.
	RuleColumn = "rule_id"
)

Variables

var (
	// IndxValidator is a validator for the "indx" field. It is called by the builders before save.
	IndxValidator func(string) error
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
)

Columns holds all SQL columns for rulesection fields.

var ForeignKeys = []string{
	"rule_id",
}

ForeignKeys holds the SQL foreign-keys that are owned by the "rule_sections" table and are not defined as standalone fields in the schema.

Functions

func And

func And(predicates ...predicate.RuleSection) predicate.RuleSection

And groups predicates with the AND operator between them.

func DescIsNil

func DescIsNil() predicate.RuleSection

DescIsNil applies the IsNil predicate on the "desc" field.

func DescNotNil

func DescNotNil() predicate.RuleSection

DescNotNil applies the NotNil predicate on the "desc" field.

func HasRule

func HasRule() predicate.RuleSection

HasRule applies the HasEdge predicate on the "rule" edge.

func HasRuleWith

func HasRuleWith(preds ...predicate.Rule) predicate.RuleSection

HasRuleWith applies the HasEdge predicate on the "rule" edge with a given conditions (other predicates).

func ID

func ID(id int) predicate.RuleSection

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.RuleSection

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.RuleSection

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.RuleSection

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.RuleSection

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.RuleSection

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.RuleSection

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.RuleSection

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.RuleSection

IDNotIn applies the NotIn predicate on the ID field.

func Indx

Indx applies equality check predicate on the "indx" field. It's identical to IndxEQ.

func IndxContains

func IndxContains(v string) predicate.RuleSection

IndxContains applies the Contains predicate on the "indx" field.

func IndxContainsFold

func IndxContainsFold(v string) predicate.RuleSection

IndxContainsFold applies the ContainsFold predicate on the "indx" field.

func IndxEQ

func IndxEQ(v string) predicate.RuleSection

IndxEQ applies the EQ predicate on the "indx" field.

func IndxEqualFold

func IndxEqualFold(v string) predicate.RuleSection

IndxEqualFold applies the EqualFold predicate on the "indx" field.

func IndxGT

func IndxGT(v string) predicate.RuleSection

IndxGT applies the GT predicate on the "indx" field.

func IndxGTE

func IndxGTE(v string) predicate.RuleSection

IndxGTE applies the GTE predicate on the "indx" field.

func IndxHasPrefix

func IndxHasPrefix(v string) predicate.RuleSection

IndxHasPrefix applies the HasPrefix predicate on the "indx" field.

func IndxHasSuffix

func IndxHasSuffix(v string) predicate.RuleSection

IndxHasSuffix applies the HasSuffix predicate on the "indx" field.

func IndxIn

func IndxIn(vs ...string) predicate.RuleSection

IndxIn applies the In predicate on the "indx" field.

func IndxLT

func IndxLT(v string) predicate.RuleSection

IndxLT applies the LT predicate on the "indx" field.

func IndxLTE

func IndxLTE(v string) predicate.RuleSection

IndxLTE applies the LTE predicate on the "indx" field.

func IndxNEQ

func IndxNEQ(v string) predicate.RuleSection

IndxNEQ applies the NEQ predicate on the "indx" field.

func IndxNotIn

func IndxNotIn(vs ...string) predicate.RuleSection

IndxNotIn applies the NotIn predicate on the "indx" field.

func Name

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.RuleSection

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.RuleSection

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.RuleSection

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.RuleSection

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.RuleSection

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.RuleSection

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.RuleSection

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.RuleSection

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.RuleSection

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.RuleSection

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.RuleSection

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.RuleSection

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.RuleSection

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.RuleSection) predicate.RuleSection

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the RuleSection queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIndx

func ByIndx(opts ...sql.OrderTermOption) OrderOption

ByIndx orders the results by the indx field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByRuleField

func ByRuleField(field string, opts ...sql.OrderTermOption) OrderOption

ByRuleField orders the results by rule field.

Jump to