Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Skill) predicate.Skill
- func DescIsNil() predicate.Skill
- func DescNotNil() predicate.Skill
- func HasAbilityScore() predicate.Skill
- func HasAbilityScoreWith(preds ...predicate.AbilityScore) predicate.Skill
- func HasCharacterSkill() predicate.Skill
- func HasCharacterSkillWith(preds ...predicate.CharacterSkill) predicate.Skill
- func ID(id int) predicate.Skill
- func IDEQ(id int) predicate.Skill
- func IDGT(id int) predicate.Skill
- func IDGTE(id int) predicate.Skill
- func IDIn(ids ...int) predicate.Skill
- func IDLT(id int) predicate.Skill
- func IDLTE(id int) predicate.Skill
- func IDNEQ(id int) predicate.Skill
- func IDNotIn(ids ...int) predicate.Skill
- func Indx(v string) predicate.Skill
- func IndxContains(v string) predicate.Skill
- func IndxContainsFold(v string) predicate.Skill
- func IndxEQ(v string) predicate.Skill
- func IndxEqualFold(v string) predicate.Skill
- func IndxGT(v string) predicate.Skill
- func IndxGTE(v string) predicate.Skill
- func IndxHasPrefix(v string) predicate.Skill
- func IndxHasSuffix(v string) predicate.Skill
- func IndxIn(vs ...string) predicate.Skill
- func IndxLT(v string) predicate.Skill
- func IndxLTE(v string) predicate.Skill
- func IndxNEQ(v string) predicate.Skill
- func IndxNotIn(vs ...string) predicate.Skill
- func Name(v string) predicate.Skill
- func NameContains(v string) predicate.Skill
- func NameContainsFold(v string) predicate.Skill
- func NameEQ(v string) predicate.Skill
- func NameEqualFold(v string) predicate.Skill
- func NameGT(v string) predicate.Skill
- func NameGTE(v string) predicate.Skill
- func NameHasPrefix(v string) predicate.Skill
- func NameHasSuffix(v string) predicate.Skill
- func NameIn(vs ...string) predicate.Skill
- func NameLT(v string) predicate.Skill
- func NameLTE(v string) predicate.Skill
- func NameNEQ(v string) predicate.Skill
- func NameNotIn(vs ...string) predicate.Skill
- func Not(p predicate.Skill) predicate.Skill
- func Or(predicates ...predicate.Skill) predicate.Skill
- func ValidColumn(column string) bool
- type OrderOption
- func ByAbilityScoreField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCharacterSkill(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByCharacterSkillCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIndx(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the skill type in the database. Label = "skill" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldIndx holds the string denoting the indx field in the database. FieldIndx = "indx" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDesc holds the string denoting the desc field in the database. FieldDesc = "desc" // EdgeAbilityScore holds the string denoting the ability_score edge name in mutations. EdgeAbilityScore = "ability_score" // EdgeCharacterSkill holds the string denoting the character_skill edge name in mutations. EdgeCharacterSkill = "character_skill" // Table holds the table name of the skill in the database. Table = "skills" // AbilityScoreTable is the table that holds the ability_score relation/edge. AbilityScoreTable = "skills" // AbilityScoreInverseTable is the table name for the AbilityScore entity. // It exists in this package in order to avoid circular dependency with the "abilityscore" package. AbilityScoreInverseTable = "ability_scores" // AbilityScoreColumn is the table column denoting the ability_score relation/edge. AbilityScoreColumn = "ability_score_skills" // CharacterSkillTable is the table that holds the character_skill relation/edge. CharacterSkillTable = "character_skills" // CharacterSkillInverseTable is the table name for the CharacterSkill entity. // It exists in this package in order to avoid circular dependency with the "characterskill" package. CharacterSkillInverseTable = "character_skills" // CharacterSkillColumn is the table column denoting the character_skill relation/edge. CharacterSkillColumn = "character_skill_skill" )
Variables ¶
var ( // IndxValidator is a validator for the "indx" field. It is called by the builders before save. IndxValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error )
Columns holds all SQL columns for skill fields.
var ForeignKeys = []string{
"ability_score_skills",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "skills" table and are not defined as standalone fields in the schema.
Functions ¶
func DescNotNil ¶
DescNotNil applies the NotNil predicate on the "desc" field.
func HasAbilityScore ¶
HasAbilityScore applies the HasEdge predicate on the "ability_score" edge.
func HasAbilityScoreWith ¶
func HasAbilityScoreWith(preds ...predicate.AbilityScore) predicate.Skill
HasAbilityScoreWith applies the HasEdge predicate on the "ability_score" edge with a given conditions (other predicates).
func HasCharacterSkill ¶
HasCharacterSkill applies the HasEdge predicate on the "character_skill" edge.
func HasCharacterSkillWith ¶
func HasCharacterSkillWith(preds ...predicate.CharacterSkill) predicate.Skill
HasCharacterSkillWith applies the HasEdge predicate on the "character_skill" edge with a given conditions (other predicates).
func IndxContains ¶
IndxContains applies the Contains predicate on the "indx" field.
func IndxContainsFold ¶
IndxContainsFold applies the ContainsFold predicate on the "indx" field.
func IndxEqualFold ¶
IndxEqualFold applies the EqualFold predicate on the "indx" field.
func IndxHasPrefix ¶
IndxHasPrefix applies the HasPrefix predicate on the "indx" field.
func IndxHasSuffix ¶
IndxHasSuffix applies the HasSuffix predicate on the "indx" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Skill queries.
func ByAbilityScoreField ¶
func ByAbilityScoreField(field string, opts ...sql.OrderTermOption) OrderOption
ByAbilityScoreField orders the results by ability_score field.
func ByCharacterSkill ¶
func ByCharacterSkill(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByCharacterSkill orders the results by character_skill terms.
func ByCharacterSkillCount ¶
func ByCharacterSkillCount(opts ...sql.OrderTermOption) OrderOption
ByCharacterSkillCount orders the results by character_skill count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIndx ¶
func ByIndx(opts ...sql.OrderTermOption) OrderOption
ByIndx orders the results by the indx field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.