Documentation
¶
Index ¶
- Constants
- Variables
- func AcBase(v int) predicate.Armor
- func AcBaseEQ(v int) predicate.Armor
- func AcBaseGT(v int) predicate.Armor
- func AcBaseGTE(v int) predicate.Armor
- func AcBaseIn(vs ...int) predicate.Armor
- func AcBaseLT(v int) predicate.Armor
- func AcBaseLTE(v int) predicate.Armor
- func AcBaseNEQ(v int) predicate.Armor
- func AcBaseNotIn(vs ...int) predicate.Armor
- func AcDexBonus(v bool) predicate.Armor
- func AcDexBonusEQ(v bool) predicate.Armor
- func AcDexBonusNEQ(v bool) predicate.Armor
- func AcMaxBonus(v int) predicate.Armor
- func AcMaxBonusEQ(v int) predicate.Armor
- func AcMaxBonusGT(v int) predicate.Armor
- func AcMaxBonusGTE(v int) predicate.Armor
- func AcMaxBonusIn(vs ...int) predicate.Armor
- func AcMaxBonusLT(v int) predicate.Armor
- func AcMaxBonusLTE(v int) predicate.Armor
- func AcMaxBonusNEQ(v int) predicate.Armor
- func AcMaxBonusNotIn(vs ...int) predicate.Armor
- func And(predicates ...predicate.Armor) predicate.Armor
- func ArmorCategoryEQ(v ArmorCategory) predicate.Armor
- func ArmorCategoryIn(vs ...ArmorCategory) predicate.Armor
- func ArmorCategoryNEQ(v ArmorCategory) predicate.Armor
- func ArmorCategoryNotIn(vs ...ArmorCategory) predicate.Armor
- func ArmorCategoryValidator(ac ArmorCategory) error
- func HasEquipment() predicate.Armor
- func HasEquipmentWith(preds ...predicate.Equipment) predicate.Armor
- func ID(id int) predicate.Armor
- func IDEQ(id int) predicate.Armor
- func IDGT(id int) predicate.Armor
- func IDGTE(id int) predicate.Armor
- func IDIn(ids ...int) predicate.Armor
- func IDLT(id int) predicate.Armor
- func IDLTE(id int) predicate.Armor
- func IDNEQ(id int) predicate.Armor
- func IDNotIn(ids ...int) predicate.Armor
- func Not(p predicate.Armor) predicate.Armor
- func Or(predicates ...predicate.Armor) predicate.Armor
- func StealthDisadvantage(v bool) predicate.Armor
- func StealthDisadvantageEQ(v bool) predicate.Armor
- func StealthDisadvantageNEQ(v bool) predicate.Armor
- func StrMinimum(v int) predicate.Armor
- func StrMinimumEQ(v int) predicate.Armor
- func StrMinimumGT(v int) predicate.Armor
- func StrMinimumGTE(v int) predicate.Armor
- func StrMinimumIn(vs ...int) predicate.Armor
- func StrMinimumLT(v int) predicate.Armor
- func StrMinimumLTE(v int) predicate.Armor
- func StrMinimumNEQ(v int) predicate.Armor
- func StrMinimumNotIn(vs ...int) predicate.Armor
- func ValidColumn(column string) bool
- type ArmorCategory
- type OrderOption
- func ByAcBase(opts ...sql.OrderTermOption) OrderOption
- func ByAcDexBonus(opts ...sql.OrderTermOption) OrderOption
- func ByAcMaxBonus(opts ...sql.OrderTermOption) OrderOption
- func ByArmorCategory(opts ...sql.OrderTermOption) OrderOption
- func ByEquipmentField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByStealthDisadvantage(opts ...sql.OrderTermOption) OrderOption
- func ByStrMinimum(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the armor type in the database. Label = "armor" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldArmorCategory holds the string denoting the armor_category field in the database. FieldArmorCategory = "armor_category" // FieldStrMinimum holds the string denoting the str_minimum field in the database. FieldStrMinimum = "str_minimum" // FieldStealthDisadvantage holds the string denoting the stealth_disadvantage field in the database. FieldStealthDisadvantage = "stealth_disadvantage" // FieldAcBase holds the string denoting the ac_base field in the database. FieldAcBase = "ac_base" // FieldAcDexBonus holds the string denoting the ac_dex_bonus field in the database. FieldAcDexBonus = "ac_dex_bonus" // FieldAcMaxBonus holds the string denoting the ac_max_bonus field in the database. FieldAcMaxBonus = "ac_max_bonus" // EdgeEquipment holds the string denoting the equipment edge name in mutations. EdgeEquipment = "equipment" // Table holds the table name of the armor in the database. Table = "armors" // EquipmentTable is the table that holds the equipment relation/edge. EquipmentTable = "armors" // EquipmentInverseTable is the table name for the Equipment entity. // It exists in this package in order to avoid circular dependency with the "equipment" package. EquipmentInverseTable = "equipment" // EquipmentColumn is the table column denoting the equipment relation/edge. EquipmentColumn = "equipment_armor" )
Variables ¶
var ( // AcBaseValidator is a validator for the "ac_base" field. It is called by the builders before save. AcBaseValidator func(int) error // DefaultAcDexBonus holds the default value on creation for the "ac_dex_bonus" field. DefaultAcDexBonus bool // DefaultAcMaxBonus holds the default value on creation for the "ac_max_bonus" field. DefaultAcMaxBonus int )
var Columns = []string{ FieldID, FieldArmorCategory, FieldStrMinimum, FieldStealthDisadvantage, FieldAcBase, FieldAcDexBonus, FieldAcMaxBonus, }
Columns holds all SQL columns for armor fields.
var ForeignKeys = []string{
"equipment_armor",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "armors" table and are not defined as standalone fields in the schema.
Functions ¶
func AcBase ¶
AcBase applies equality check predicate on the "ac_base" field. It's identical to AcBaseEQ.
func AcBaseNotIn ¶
AcBaseNotIn applies the NotIn predicate on the "ac_base" field.
func AcDexBonus ¶
AcDexBonus applies equality check predicate on the "ac_dex_bonus" field. It's identical to AcDexBonusEQ.
func AcDexBonusEQ ¶
AcDexBonusEQ applies the EQ predicate on the "ac_dex_bonus" field.
func AcDexBonusNEQ ¶
AcDexBonusNEQ applies the NEQ predicate on the "ac_dex_bonus" field.
func AcMaxBonus ¶
AcMaxBonus applies equality check predicate on the "ac_max_bonus" field. It's identical to AcMaxBonusEQ.
func AcMaxBonusEQ ¶
AcMaxBonusEQ applies the EQ predicate on the "ac_max_bonus" field.
func AcMaxBonusGT ¶
AcMaxBonusGT applies the GT predicate on the "ac_max_bonus" field.
func AcMaxBonusGTE ¶
AcMaxBonusGTE applies the GTE predicate on the "ac_max_bonus" field.
func AcMaxBonusIn ¶
AcMaxBonusIn applies the In predicate on the "ac_max_bonus" field.
func AcMaxBonusLT ¶
AcMaxBonusLT applies the LT predicate on the "ac_max_bonus" field.
func AcMaxBonusLTE ¶
AcMaxBonusLTE applies the LTE predicate on the "ac_max_bonus" field.
func AcMaxBonusNEQ ¶
AcMaxBonusNEQ applies the NEQ predicate on the "ac_max_bonus" field.
func AcMaxBonusNotIn ¶
AcMaxBonusNotIn applies the NotIn predicate on the "ac_max_bonus" field.
func ArmorCategoryEQ ¶
func ArmorCategoryEQ(v ArmorCategory) predicate.Armor
ArmorCategoryEQ applies the EQ predicate on the "armor_category" field.
func ArmorCategoryIn ¶
func ArmorCategoryIn(vs ...ArmorCategory) predicate.Armor
ArmorCategoryIn applies the In predicate on the "armor_category" field.
func ArmorCategoryNEQ ¶
func ArmorCategoryNEQ(v ArmorCategory) predicate.Armor
ArmorCategoryNEQ applies the NEQ predicate on the "armor_category" field.
func ArmorCategoryNotIn ¶
func ArmorCategoryNotIn(vs ...ArmorCategory) predicate.Armor
ArmorCategoryNotIn applies the NotIn predicate on the "armor_category" field.
func ArmorCategoryValidator ¶
func ArmorCategoryValidator(ac ArmorCategory) error
ArmorCategoryValidator is a validator for the "armor_category" field enum values. It is called by the builders before save.
func HasEquipment ¶
HasEquipment applies the HasEdge predicate on the "equipment" edge.
func HasEquipmentWith ¶
HasEquipmentWith applies the HasEdge predicate on the "equipment" edge with a given conditions (other predicates).
func StealthDisadvantage ¶
StealthDisadvantage applies equality check predicate on the "stealth_disadvantage" field. It's identical to StealthDisadvantageEQ.
func StealthDisadvantageEQ ¶
StealthDisadvantageEQ applies the EQ predicate on the "stealth_disadvantage" field.
func StealthDisadvantageNEQ ¶
StealthDisadvantageNEQ applies the NEQ predicate on the "stealth_disadvantage" field.
func StrMinimum ¶
StrMinimum applies equality check predicate on the "str_minimum" field. It's identical to StrMinimumEQ.
func StrMinimumEQ ¶
StrMinimumEQ applies the EQ predicate on the "str_minimum" field.
func StrMinimumGT ¶
StrMinimumGT applies the GT predicate on the "str_minimum" field.
func StrMinimumGTE ¶
StrMinimumGTE applies the GTE predicate on the "str_minimum" field.
func StrMinimumIn ¶
StrMinimumIn applies the In predicate on the "str_minimum" field.
func StrMinimumLT ¶
StrMinimumLT applies the LT predicate on the "str_minimum" field.
func StrMinimumLTE ¶
StrMinimumLTE applies the LTE predicate on the "str_minimum" field.
func StrMinimumNEQ ¶
StrMinimumNEQ applies the NEQ predicate on the "str_minimum" field.
func StrMinimumNotIn ¶
StrMinimumNotIn applies the NotIn predicate on the "str_minimum" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type ArmorCategory ¶
type ArmorCategory string
ArmorCategory defines the type for the "armor_category" enum field.
const ( ArmorCategoryLight ArmorCategory = "light" ArmorCategoryMedium ArmorCategory = "medium" ArmorCategoryHeavy ArmorCategory = "heavy" ArmorCategoryShield ArmorCategory = "shield" )
ArmorCategory values.
func (ArmorCategory) MarshalGQL ¶
func (e ArmorCategory) MarshalGQL(w io.Writer)
MarshalGQL implements graphql.Marshaler interface.
func (ArmorCategory) String ¶
func (ac ArmorCategory) String() string
func (*ArmorCategory) UnmarshalGQL ¶
func (e *ArmorCategory) UnmarshalGQL(val interface{}) error
UnmarshalGQL implements graphql.Unmarshaler interface.
type OrderOption ¶
OrderOption defines the ordering options for the Armor queries.
func ByAcBase ¶
func ByAcBase(opts ...sql.OrderTermOption) OrderOption
ByAcBase orders the results by the ac_base field.
func ByAcDexBonus ¶
func ByAcDexBonus(opts ...sql.OrderTermOption) OrderOption
ByAcDexBonus orders the results by the ac_dex_bonus field.
func ByAcMaxBonus ¶
func ByAcMaxBonus(opts ...sql.OrderTermOption) OrderOption
ByAcMaxBonus orders the results by the ac_max_bonus field.
func ByArmorCategory ¶
func ByArmorCategory(opts ...sql.OrderTermOption) OrderOption
ByArmorCategory orders the results by the armor_category field.
func ByEquipmentField ¶
func ByEquipmentField(field string, opts ...sql.OrderTermOption) OrderOption
ByEquipmentField orders the results by equipment field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByStealthDisadvantage ¶
func ByStealthDisadvantage(opts ...sql.OrderTermOption) OrderOption
ByStealthDisadvantage orders the results by the stealth_disadvantage field.
func ByStrMinimum ¶
func ByStrMinimum(opts ...sql.OrderTermOption) OrderOption
ByStrMinimum orders the results by the str_minimum field.