Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.CharacterSkill) predicate.CharacterSkill
- func HasCharacter() predicate.CharacterSkill
- func HasCharacterAbilityScore() predicate.CharacterSkill
- func HasCharacterAbilityScoreWith(preds ...predicate.CharacterAbilityScore) predicate.CharacterSkill
- func HasCharacterProficiency() predicate.CharacterSkill
- func HasCharacterProficiencyWith(preds ...predicate.CharacterProficiency) predicate.CharacterSkill
- func HasCharacterWith(preds ...predicate.Character) predicate.CharacterSkill
- func HasSkill() predicate.CharacterSkill
- func HasSkillWith(preds ...predicate.Skill) predicate.CharacterSkill
- func ID(id int) predicate.CharacterSkill
- func IDEQ(id int) predicate.CharacterSkill
- func IDGT(id int) predicate.CharacterSkill
- func IDGTE(id int) predicate.CharacterSkill
- func IDIn(ids ...int) predicate.CharacterSkill
- func IDLT(id int) predicate.CharacterSkill
- func IDLTE(id int) predicate.CharacterSkill
- func IDNEQ(id int) predicate.CharacterSkill
- func IDNotIn(ids ...int) predicate.CharacterSkill
- func Not(p predicate.CharacterSkill) predicate.CharacterSkill
- func Or(predicates ...predicate.CharacterSkill) predicate.CharacterSkill
- func Proficient(v bool) predicate.CharacterSkill
- func ProficientEQ(v bool) predicate.CharacterSkill
- func ProficientNEQ(v bool) predicate.CharacterSkill
- func ValidColumn(column string) bool
- type OrderOption
- func ByCharacterAbilityScoreField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCharacterField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCharacterProficiencyField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByProficient(opts ...sql.OrderTermOption) OrderOption
- func BySkillField(field string, opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the characterskill type in the database. Label = "character_skill" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldProficient holds the string denoting the proficient field in the database. FieldProficient = "proficient" // EdgeCharacter holds the string denoting the character edge name in mutations. EdgeCharacter = "character" // EdgeSkill holds the string denoting the skill edge name in mutations. EdgeSkill = "skill" // EdgeCharacterAbilityScore holds the string denoting the character_ability_score edge name in mutations. EdgeCharacterAbilityScore = "character_ability_score" // EdgeCharacterProficiency holds the string denoting the character_proficiency edge name in mutations. EdgeCharacterProficiency = "character_proficiency" // Table holds the table name of the characterskill in the database. Table = "character_skills" // CharacterTable is the table that holds the character relation/edge. CharacterTable = "character_skills" // CharacterInverseTable is the table name for the Character entity. // It exists in this package in order to avoid circular dependency with the "character" package. CharacterInverseTable = "characters" // CharacterColumn is the table column denoting the character relation/edge. CharacterColumn = "character_character_skills" // SkillTable is the table that holds the skill relation/edge. SkillTable = "character_skills" // SkillInverseTable is the table name for the Skill entity. // It exists in this package in order to avoid circular dependency with the "skill" package. SkillInverseTable = "skills" // SkillColumn is the table column denoting the skill relation/edge. SkillColumn = "character_skill_skill" // CharacterAbilityScoreTable is the table that holds the character_ability_score relation/edge. CharacterAbilityScoreTable = "character_skills" // CharacterAbilityScoreInverseTable is the table name for the CharacterAbilityScore entity. // It exists in this package in order to avoid circular dependency with the "characterabilityscore" package. CharacterAbilityScoreInverseTable = "character_ability_scores" // CharacterAbilityScoreColumn is the table column denoting the character_ability_score relation/edge. CharacterAbilityScoreColumn = "character_skill_character_ability_score" // CharacterProficiencyTable is the table that holds the character_proficiency relation/edge. CharacterProficiencyTable = "character_proficiencies" // CharacterProficiencyInverseTable is the table name for the CharacterProficiency entity. // It exists in this package in order to avoid circular dependency with the "characterproficiency" package. CharacterProficiencyInverseTable = "character_proficiencies" // CharacterProficiencyColumn is the table column denoting the character_proficiency relation/edge. CharacterProficiencyColumn = "character_skill_character_proficiency" )
Variables ¶
var Columns = []string{ FieldID, FieldProficient, }
Columns holds all SQL columns for characterskill fields.
var ( // DefaultProficient holds the default value on creation for the "proficient" field. DefaultProficient bool )
var ForeignKeys = []string{
"character_character_skills",
"character_skill_skill",
"character_skill_character_ability_score",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "character_skills" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.CharacterSkill) predicate.CharacterSkill
And groups predicates with the AND operator between them.
func HasCharacter ¶
func HasCharacter() predicate.CharacterSkill
HasCharacter applies the HasEdge predicate on the "character" edge.
func HasCharacterAbilityScore ¶
func HasCharacterAbilityScore() predicate.CharacterSkill
HasCharacterAbilityScore applies the HasEdge predicate on the "character_ability_score" edge.
func HasCharacterAbilityScoreWith ¶
func HasCharacterAbilityScoreWith(preds ...predicate.CharacterAbilityScore) predicate.CharacterSkill
HasCharacterAbilityScoreWith applies the HasEdge predicate on the "character_ability_score" edge with a given conditions (other predicates).
func HasCharacterProficiency ¶
func HasCharacterProficiency() predicate.CharacterSkill
HasCharacterProficiency applies the HasEdge predicate on the "character_proficiency" edge.
func HasCharacterProficiencyWith ¶
func HasCharacterProficiencyWith(preds ...predicate.CharacterProficiency) predicate.CharacterSkill
HasCharacterProficiencyWith applies the HasEdge predicate on the "character_proficiency" edge with a given conditions (other predicates).
func HasCharacterWith ¶
func HasCharacterWith(preds ...predicate.Character) predicate.CharacterSkill
HasCharacterWith applies the HasEdge predicate on the "character" edge with a given conditions (other predicates).
func HasSkill ¶
func HasSkill() predicate.CharacterSkill
HasSkill applies the HasEdge predicate on the "skill" edge.
func HasSkillWith ¶
func HasSkillWith(preds ...predicate.Skill) predicate.CharacterSkill
HasSkillWith applies the HasEdge predicate on the "skill" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.CharacterSkill
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.CharacterSkill
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.CharacterSkill
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.CharacterSkill
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.CharacterSkill
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.CharacterSkill
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.CharacterSkill
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.CharacterSkill
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.CharacterSkill) predicate.CharacterSkill
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.CharacterSkill) predicate.CharacterSkill
Or groups predicates with the OR operator between them.
func Proficient ¶
func Proficient(v bool) predicate.CharacterSkill
Proficient applies equality check predicate on the "proficient" field. It's identical to ProficientEQ.
func ProficientEQ ¶
func ProficientEQ(v bool) predicate.CharacterSkill
ProficientEQ applies the EQ predicate on the "proficient" field.
func ProficientNEQ ¶
func ProficientNEQ(v bool) predicate.CharacterSkill
ProficientNEQ applies the NEQ predicate on the "proficient" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the CharacterSkill queries.
func ByCharacterAbilityScoreField ¶
func ByCharacterAbilityScoreField(field string, opts ...sql.OrderTermOption) OrderOption
ByCharacterAbilityScoreField orders the results by character_ability_score field.
func ByCharacterField ¶
func ByCharacterField(field string, opts ...sql.OrderTermOption) OrderOption
ByCharacterField orders the results by character field.
func ByCharacterProficiencyField ¶
func ByCharacterProficiencyField(field string, opts ...sql.OrderTermOption) OrderOption
ByCharacterProficiencyField orders the results by character_proficiency field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByProficient ¶
func ByProficient(opts ...sql.OrderTermOption) OrderOption
ByProficient orders the results by the proficient field.
func BySkillField ¶
func BySkillField(field string, opts ...sql.OrderTermOption) OrderOption
BySkillField orders the results by skill field.