Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Equipment) predicate.Equipment
- func EquipmentCategoryEQ(v EquipmentCategory) predicate.Equipment
- func EquipmentCategoryIn(vs ...EquipmentCategory) predicate.Equipment
- func EquipmentCategoryNEQ(v EquipmentCategory) predicate.Equipment
- func EquipmentCategoryNotIn(vs ...EquipmentCategory) predicate.Equipment
- func EquipmentCategoryValidator(ec EquipmentCategory) error
- func HasArmor() predicate.Equipment
- func HasArmorWith(preds ...predicate.Armor) predicate.Equipment
- func HasCost() predicate.Equipment
- func HasCostWith(preds ...predicate.Cost) predicate.Equipment
- func HasEquipmentEntries() predicate.Equipment
- func HasEquipmentEntriesWith(preds ...predicate.EquipmentEntry) predicate.Equipment
- func HasGear() predicate.Equipment
- func HasGearWith(preds ...predicate.Gear) predicate.Equipment
- func HasTool() predicate.Equipment
- func HasToolWith(preds ...predicate.Tool) predicate.Equipment
- func HasVehicle() predicate.Equipment
- func HasVehicleWith(preds ...predicate.Vehicle) predicate.Equipment
- func HasWeapon() predicate.Equipment
- func HasWeaponWith(preds ...predicate.Weapon) predicate.Equipment
- func ID(id int) predicate.Equipment
- func IDEQ(id int) predicate.Equipment
- func IDGT(id int) predicate.Equipment
- func IDGTE(id int) predicate.Equipment
- func IDIn(ids ...int) predicate.Equipment
- func IDLT(id int) predicate.Equipment
- func IDLTE(id int) predicate.Equipment
- func IDNEQ(id int) predicate.Equipment
- func IDNotIn(ids ...int) predicate.Equipment
- func Indx(v string) predicate.Equipment
- func IndxContains(v string) predicate.Equipment
- func IndxContainsFold(v string) predicate.Equipment
- func IndxEQ(v string) predicate.Equipment
- func IndxEqualFold(v string) predicate.Equipment
- func IndxGT(v string) predicate.Equipment
- func IndxGTE(v string) predicate.Equipment
- func IndxHasPrefix(v string) predicate.Equipment
- func IndxHasSuffix(v string) predicate.Equipment
- func IndxIn(vs ...string) predicate.Equipment
- func IndxLT(v string) predicate.Equipment
- func IndxLTE(v string) predicate.Equipment
- func IndxNEQ(v string) predicate.Equipment
- func IndxNotIn(vs ...string) predicate.Equipment
- func Name(v string) predicate.Equipment
- func NameContains(v string) predicate.Equipment
- func NameContainsFold(v string) predicate.Equipment
- func NameEQ(v string) predicate.Equipment
- func NameEqualFold(v string) predicate.Equipment
- func NameGT(v string) predicate.Equipment
- func NameGTE(v string) predicate.Equipment
- func NameHasPrefix(v string) predicate.Equipment
- func NameHasSuffix(v string) predicate.Equipment
- func NameIn(vs ...string) predicate.Equipment
- func NameLT(v string) predicate.Equipment
- func NameLTE(v string) predicate.Equipment
- func NameNEQ(v string) predicate.Equipment
- func NameNotIn(vs ...string) predicate.Equipment
- func Not(p predicate.Equipment) predicate.Equipment
- func Or(predicates ...predicate.Equipment) predicate.Equipment
- func ValidColumn(column string) bool
- func Weight(v float64) predicate.Equipment
- func WeightEQ(v float64) predicate.Equipment
- func WeightGT(v float64) predicate.Equipment
- func WeightGTE(v float64) predicate.Equipment
- func WeightIn(vs ...float64) predicate.Equipment
- func WeightIsNil() predicate.Equipment
- func WeightLT(v float64) predicate.Equipment
- func WeightLTE(v float64) predicate.Equipment
- func WeightNEQ(v float64) predicate.Equipment
- func WeightNotIn(vs ...float64) predicate.Equipment
- func WeightNotNil() predicate.Equipment
- type EquipmentCategory
- type OrderOption
- func ByArmorField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByCostField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByEquipmentCategory(opts ...sql.OrderTermOption) OrderOption
- func ByEquipmentEntries(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByEquipmentEntriesCount(opts ...sql.OrderTermOption) OrderOption
- func ByGearField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIndx(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByToolField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByVehicleField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByWeaponField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByWeight(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the equipment type in the database. Label = "equipment" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldIndx holds the string denoting the indx field in the database. FieldIndx = "indx" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldEquipmentCategory holds the string denoting the equipment_category field in the database. FieldEquipmentCategory = "equipment_category" // FieldWeight holds the string denoting the weight field in the database. FieldWeight = "weight" // EdgeCost holds the string denoting the cost edge name in mutations. EdgeCost = "cost" // EdgeGear holds the string denoting the gear edge name in mutations. EdgeGear = "gear" // EdgeTool holds the string denoting the tool edge name in mutations. EdgeTool = "tool" // EdgeWeapon holds the string denoting the weapon edge name in mutations. EdgeWeapon = "weapon" // EdgeVehicle holds the string denoting the vehicle edge name in mutations. EdgeVehicle = "vehicle" // EdgeArmor holds the string denoting the armor edge name in mutations. EdgeArmor = "armor" // EdgeEquipmentEntries holds the string denoting the equipment_entries edge name in mutations. EdgeEquipmentEntries = "equipment_entries" // Table holds the table name of the equipment in the database. Table = "equipment" // CostTable is the table that holds the cost relation/edge. CostTable = "costs" // CostInverseTable is the table name for the Cost entity. // It exists in this package in order to avoid circular dependency with the "cost" package. CostInverseTable = "costs" // CostColumn is the table column denoting the cost relation/edge. CostColumn = "equipment_cost" // GearTable is the table that holds the gear relation/edge. GearTable = "gears" // GearInverseTable is the table name for the Gear entity. // It exists in this package in order to avoid circular dependency with the "gear" package. GearInverseTable = "gears" // GearColumn is the table column denoting the gear relation/edge. GearColumn = "equipment_gear" // ToolTable is the table that holds the tool relation/edge. ToolTable = "tools" // ToolInverseTable is the table name for the Tool entity. // It exists in this package in order to avoid circular dependency with the "tool" package. ToolInverseTable = "tools" // ToolColumn is the table column denoting the tool relation/edge. ToolColumn = "equipment_tool" // WeaponTable is the table that holds the weapon relation/edge. WeaponTable = "weapons" // WeaponInverseTable is the table name for the Weapon entity. // It exists in this package in order to avoid circular dependency with the "weapon" package. WeaponInverseTable = "weapons" // WeaponColumn is the table column denoting the weapon relation/edge. WeaponColumn = "equipment_weapon" // VehicleTable is the table that holds the vehicle relation/edge. VehicleTable = "vehicles" // VehicleInverseTable is the table name for the Vehicle entity. // It exists in this package in order to avoid circular dependency with the "vehicle" package. VehicleInverseTable = "vehicles" // VehicleColumn is the table column denoting the vehicle relation/edge. VehicleColumn = "equipment_vehicle" // ArmorTable is the table that holds the armor relation/edge. ArmorTable = "armors" // ArmorInverseTable is the table name for the Armor entity. // It exists in this package in order to avoid circular dependency with the "armor" package. ArmorInverseTable = "armors" // ArmorColumn is the table column denoting the armor relation/edge. ArmorColumn = "equipment_armor" // EquipmentEntriesTable is the table that holds the equipment_entries relation/edge. EquipmentEntriesTable = "equipment_entries" // EquipmentEntriesInverseTable is the table name for the EquipmentEntry entity. // It exists in this package in order to avoid circular dependency with the "equipmententry" package. EquipmentEntriesInverseTable = "equipment_entries" // EquipmentEntriesColumn is the table column denoting the equipment_entries relation/edge. EquipmentEntriesColumn = "equipment_entry_equipment" )
Variables ¶
var ( // IndxValidator is a validator for the "indx" field. It is called by the builders before save. IndxValidator func(string) error // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error )
var Columns = []string{ FieldID, FieldIndx, FieldName, FieldEquipmentCategory, FieldWeight, }
Columns holds all SQL columns for equipment fields.
Functions ¶
func EquipmentCategoryEQ ¶
func EquipmentCategoryEQ(v EquipmentCategory) predicate.Equipment
EquipmentCategoryEQ applies the EQ predicate on the "equipment_category" field.
func EquipmentCategoryIn ¶
func EquipmentCategoryIn(vs ...EquipmentCategory) predicate.Equipment
EquipmentCategoryIn applies the In predicate on the "equipment_category" field.
func EquipmentCategoryNEQ ¶
func EquipmentCategoryNEQ(v EquipmentCategory) predicate.Equipment
EquipmentCategoryNEQ applies the NEQ predicate on the "equipment_category" field.
func EquipmentCategoryNotIn ¶
func EquipmentCategoryNotIn(vs ...EquipmentCategory) predicate.Equipment
EquipmentCategoryNotIn applies the NotIn predicate on the "equipment_category" field.
func EquipmentCategoryValidator ¶
func EquipmentCategoryValidator(ec EquipmentCategory) error
EquipmentCategoryValidator is a validator for the "equipment_category" field enum values. It is called by the builders before save.
func HasArmorWith ¶
HasArmorWith applies the HasEdge predicate on the "armor" edge with a given conditions (other predicates).
func HasCostWith ¶
HasCostWith applies the HasEdge predicate on the "cost" edge with a given conditions (other predicates).
func HasEquipmentEntries ¶
HasEquipmentEntries applies the HasEdge predicate on the "equipment_entries" edge.
func HasEquipmentEntriesWith ¶
func HasEquipmentEntriesWith(preds ...predicate.EquipmentEntry) predicate.Equipment
HasEquipmentEntriesWith applies the HasEdge predicate on the "equipment_entries" edge with a given conditions (other predicates).
func HasGearWith ¶
HasGearWith applies the HasEdge predicate on the "gear" edge with a given conditions (other predicates).
func HasToolWith ¶
HasToolWith applies the HasEdge predicate on the "tool" edge with a given conditions (other predicates).
func HasVehicle ¶
HasVehicle applies the HasEdge predicate on the "vehicle" edge.
func HasVehicleWith ¶
HasVehicleWith applies the HasEdge predicate on the "vehicle" edge with a given conditions (other predicates).
func HasWeaponWith ¶
HasWeaponWith applies the HasEdge predicate on the "weapon" edge with a given conditions (other predicates).
func IndxContains ¶
IndxContains applies the Contains predicate on the "indx" field.
func IndxContainsFold ¶
IndxContainsFold applies the ContainsFold predicate on the "indx" field.
func IndxEqualFold ¶
IndxEqualFold applies the EqualFold predicate on the "indx" field.
func IndxHasPrefix ¶
IndxHasPrefix applies the HasPrefix predicate on the "indx" field.
func IndxHasSuffix ¶
IndxHasSuffix applies the HasSuffix predicate on the "indx" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Weight ¶
Weight applies equality check predicate on the "weight" field. It's identical to WeightEQ.
func WeightIsNil ¶
WeightIsNil applies the IsNil predicate on the "weight" field.
func WeightNotIn ¶
WeightNotIn applies the NotIn predicate on the "weight" field.
func WeightNotNil ¶
WeightNotNil applies the NotNil predicate on the "weight" field.
Types ¶
type EquipmentCategory ¶
type EquipmentCategory string
EquipmentCategory defines the type for the "equipment_category" enum field.
const ( EquipmentCategoryGear EquipmentCategory = "GEAR" EquipmentCategoryTool EquipmentCategory = "TOOL" EquipmentCategoryWeapon EquipmentCategory = "WEAPON" EquipmentCategoryVehicle EquipmentCategory = "VEHICLE" EquipmentCategoryArmor EquipmentCategory = "ARMOR" )
EquipmentCategory values.
func (EquipmentCategory) MarshalGQL ¶
func (e EquipmentCategory) MarshalGQL(w io.Writer)
MarshalGQL implements graphql.Marshaler interface.
func (EquipmentCategory) String ¶
func (ec EquipmentCategory) String() string
func (*EquipmentCategory) UnmarshalGQL ¶
func (e *EquipmentCategory) UnmarshalGQL(val interface{}) error
UnmarshalGQL implements graphql.Unmarshaler interface.
type OrderOption ¶
OrderOption defines the ordering options for the Equipment queries.
func ByArmorField ¶
func ByArmorField(field string, opts ...sql.OrderTermOption) OrderOption
ByArmorField orders the results by armor field.
func ByCostField ¶
func ByCostField(field string, opts ...sql.OrderTermOption) OrderOption
ByCostField orders the results by cost field.
func ByEquipmentCategory ¶
func ByEquipmentCategory(opts ...sql.OrderTermOption) OrderOption
ByEquipmentCategory orders the results by the equipment_category field.
func ByEquipmentEntries ¶
func ByEquipmentEntries(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByEquipmentEntries orders the results by equipment_entries terms.
func ByEquipmentEntriesCount ¶
func ByEquipmentEntriesCount(opts ...sql.OrderTermOption) OrderOption
ByEquipmentEntriesCount orders the results by equipment_entries count.
func ByGearField ¶
func ByGearField(field string, opts ...sql.OrderTermOption) OrderOption
ByGearField orders the results by gear field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIndx ¶
func ByIndx(opts ...sql.OrderTermOption) OrderOption
ByIndx orders the results by the indx field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByToolField ¶
func ByToolField(field string, opts ...sql.OrderTermOption) OrderOption
ByToolField orders the results by tool field.
func ByVehicleField ¶
func ByVehicleField(field string, opts ...sql.OrderTermOption) OrderOption
ByVehicleField orders the results by vehicle field.
func ByWeaponField ¶
func ByWeaponField(field string, opts ...sql.OrderTermOption) OrderOption
ByWeaponField orders the results by weapon field.
func ByWeight ¶
func ByWeight(opts ...sql.OrderTermOption) OrderOption
ByWeight orders the results by the weight field.