Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ProficiencyChoice) predicate.ProficiencyChoice
- func Choose(v int) predicate.ProficiencyChoice
- func ChooseEQ(v int) predicate.ProficiencyChoice
- func ChooseGT(v int) predicate.ProficiencyChoice
- func ChooseGTE(v int) predicate.ProficiencyChoice
- func ChooseIn(vs ...int) predicate.ProficiencyChoice
- func ChooseLT(v int) predicate.ProficiencyChoice
- func ChooseLTE(v int) predicate.ProficiencyChoice
- func ChooseNEQ(v int) predicate.ProficiencyChoice
- func ChooseNotIn(vs ...int) predicate.ProficiencyChoice
- func HasClass() predicate.ProficiencyChoice
- func HasClassWith(preds ...predicate.Class) predicate.ProficiencyChoice
- func HasProficiencies() predicate.ProficiencyChoice
- func HasProficienciesWith(preds ...predicate.Proficiency) predicate.ProficiencyChoice
- func HasRace() predicate.ProficiencyChoice
- func HasRaceWith(preds ...predicate.Race) predicate.ProficiencyChoice
- func ID(id int) predicate.ProficiencyChoice
- func IDEQ(id int) predicate.ProficiencyChoice
- func IDGT(id int) predicate.ProficiencyChoice
- func IDGTE(id int) predicate.ProficiencyChoice
- func IDIn(ids ...int) predicate.ProficiencyChoice
- func IDLT(id int) predicate.ProficiencyChoice
- func IDLTE(id int) predicate.ProficiencyChoice
- func IDNEQ(id int) predicate.ProficiencyChoice
- func IDNotIn(ids ...int) predicate.ProficiencyChoice
- func Not(p predicate.ProficiencyChoice) predicate.ProficiencyChoice
- func Or(predicates ...predicate.ProficiencyChoice) predicate.ProficiencyChoice
- func ValidColumn(column string) bool
- type OrderOption
- func ByChoose(opts ...sql.OrderTermOption) OrderOption
- func ByClassField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByProficiencies(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByProficienciesCount(opts ...sql.OrderTermOption) OrderOption
- func ByRaceField(field string, opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the proficiencychoice type in the database. Label = "proficiency_choice" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldChoose holds the string denoting the choose field in the database. FieldChoose = "choose" // FieldDesc holds the string denoting the desc field in the database. FieldDesc = "desc" // EdgeProficiencies holds the string denoting the proficiencies edge name in mutations. EdgeProficiencies = "proficiencies" // EdgeRace holds the string denoting the race edge name in mutations. EdgeRace = "race" // EdgeClass holds the string denoting the class edge name in mutations. EdgeClass = "class" // Table holds the table name of the proficiencychoice in the database. Table = "proficiency_choices" // ProficienciesTable is the table that holds the proficiencies relation/edge. The primary key declared below. ProficienciesTable = "proficiency_choice_proficiencies" // ProficienciesInverseTable is the table name for the Proficiency entity. // It exists in this package in order to avoid circular dependency with the "proficiency" package. ProficienciesInverseTable = "proficiencies" // RaceTable is the table that holds the race relation/edge. RaceTable = "proficiency_choices" // RaceInverseTable is the table name for the Race entity. // It exists in this package in order to avoid circular dependency with the "race" package. RaceInverseTable = "races" // RaceColumn is the table column denoting the race relation/edge. RaceColumn = "race_starting_proficiency_options" // ClassTable is the table that holds the class relation/edge. ClassTable = "proficiency_choices" // ClassInverseTable is the table name for the Class entity. // It exists in this package in order to avoid circular dependency with the "class" package. ClassInverseTable = "classes" // ClassColumn is the table column denoting the class relation/edge. ClassColumn = "class_proficiency_options" )
Variables ¶
var ( // ChooseValidator is a validator for the "choose" field. It is called by the builders before save. ChooseValidator func(int) error )
var Columns = []string{ FieldID, FieldChoose, FieldDesc, }
Columns holds all SQL columns for proficiencychoice fields.
var ForeignKeys = []string{
"class_proficiency_options",
"race_starting_proficiency_options",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "proficiency_choices" table and are not defined as standalone fields in the schema.
var ( // ProficienciesPrimaryKey and ProficienciesColumn2 are the table columns denoting the // primary key for the proficiencies relation (M2M). ProficienciesPrimaryKey = []string{"proficiency_choice_id", "proficiency_id"} )
Functions ¶
func And ¶
func And(predicates ...predicate.ProficiencyChoice) predicate.ProficiencyChoice
And groups predicates with the AND operator between them.
func Choose ¶
func Choose(v int) predicate.ProficiencyChoice
Choose applies equality check predicate on the "choose" field. It's identical to ChooseEQ.
func ChooseEQ ¶
func ChooseEQ(v int) predicate.ProficiencyChoice
ChooseEQ applies the EQ predicate on the "choose" field.
func ChooseGT ¶
func ChooseGT(v int) predicate.ProficiencyChoice
ChooseGT applies the GT predicate on the "choose" field.
func ChooseGTE ¶
func ChooseGTE(v int) predicate.ProficiencyChoice
ChooseGTE applies the GTE predicate on the "choose" field.
func ChooseIn ¶
func ChooseIn(vs ...int) predicate.ProficiencyChoice
ChooseIn applies the In predicate on the "choose" field.
func ChooseLT ¶
func ChooseLT(v int) predicate.ProficiencyChoice
ChooseLT applies the LT predicate on the "choose" field.
func ChooseLTE ¶
func ChooseLTE(v int) predicate.ProficiencyChoice
ChooseLTE applies the LTE predicate on the "choose" field.
func ChooseNEQ ¶
func ChooseNEQ(v int) predicate.ProficiencyChoice
ChooseNEQ applies the NEQ predicate on the "choose" field.
func ChooseNotIn ¶
func ChooseNotIn(vs ...int) predicate.ProficiencyChoice
ChooseNotIn applies the NotIn predicate on the "choose" field.
func HasClass ¶
func HasClass() predicate.ProficiencyChoice
HasClass applies the HasEdge predicate on the "class" edge.
func HasClassWith ¶
func HasClassWith(preds ...predicate.Class) predicate.ProficiencyChoice
HasClassWith applies the HasEdge predicate on the "class" edge with a given conditions (other predicates).
func HasProficiencies ¶
func HasProficiencies() predicate.ProficiencyChoice
HasProficiencies applies the HasEdge predicate on the "proficiencies" edge.
func HasProficienciesWith ¶
func HasProficienciesWith(preds ...predicate.Proficiency) predicate.ProficiencyChoice
HasProficienciesWith applies the HasEdge predicate on the "proficiencies" edge with a given conditions (other predicates).
func HasRace ¶
func HasRace() predicate.ProficiencyChoice
HasRace applies the HasEdge predicate on the "race" edge.
func HasRaceWith ¶
func HasRaceWith(preds ...predicate.Race) predicate.ProficiencyChoice
HasRaceWith applies the HasEdge predicate on the "race" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.ProficiencyChoice
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.ProficiencyChoice
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.ProficiencyChoice
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.ProficiencyChoice
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.ProficiencyChoice
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.ProficiencyChoice
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.ProficiencyChoice
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.ProficiencyChoice
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.ProficiencyChoice) predicate.ProficiencyChoice
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ProficiencyChoice) predicate.ProficiencyChoice
Or groups predicates with the OR operator between them.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ProficiencyChoice queries.
func ByChoose ¶
func ByChoose(opts ...sql.OrderTermOption) OrderOption
ByChoose orders the results by the choose field.
func ByClassField ¶
func ByClassField(field string, opts ...sql.OrderTermOption) OrderOption
ByClassField orders the results by class field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByProficiencies ¶
func ByProficiencies(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByProficiencies orders the results by proficiencies terms.
func ByProficienciesCount ¶
func ByProficienciesCount(opts ...sql.OrderTermOption) OrderOption
ByProficienciesCount orders the results by proficiencies count.
func ByRaceField ¶
func ByRaceField(field string, opts ...sql.OrderTermOption) OrderOption
ByRaceField orders the results by race field.